@@ -69,11 +69,6 @@ class NoRetcodeException(ConnectionException):
     """
     pass
 
-class NoPromptException(ConnectionException):
-    """ is raised when no prompt could be retreived on time
-    """
-    pass
-
 #############
 #
 # Connections
@@ -165,27 +160,24 @@ class ConnectionBase(object):
         self._expect(self.prompt, timeout=timeout or self.default_timeout)
 
 
-    def wait_for_prompt(self, timeout=None):
+    def wait_for_prompt(self, timeout=-1):
         """
         """
         self.log("wait_for_prompt({}".format(
             timeout,
         ))
-        timeout = timeout or self.first_prompt_timeout
         end_time = time.time() + timeout
         while time.time() <= end_time:
             self.log("try prompt")
             try:
                 self.expect_prompt(timeout)
                 self._logger.debug("ready")
-                return
+                break
             except (pexpect.EOF, pexpect.TIMEOUT) as e:
                 self.log("could not retreive prompt")
                 self.close()
                 self.log("sleep before retry")
                 time.sleep(3)
-        raise NoPromptException(
-                "could not retreive prompt in {} seconds".format(timeout))
 
     def cmd(self, msg, timeout=-1, expect=None, do_retcode=True):
         """ send a shell command and retreive its output.
@@ -196,12 +188,11 @@ class ConnectionBase(object):
             timeout or self.default_timeout,
             do_retcode,
         ))
-        self.wait_for_prompt()
+        self.wait_for_prompt(self.first_prompt_timeout)
         prepped_msg = self._prep_cmdmessage(msg, do_retcode)
         self._sendline(prepped_msg)
         try:
             self._expect(expect or self.prompt, timeout=timeout or self.default_timeout)
-            out = self._prep_cmdoutput(self.exp.before, prepped_msg, do_retcode)
             self._logger.debug("SUCCESS: cmd({}) result='{}' expect-match='{}'".format(
                 str(msg)[:15].encode("string_escape") + ("[...]" if len(str(msg)) > 15 else ""),
                 str(self.exp.before)[:50].encode("string-escape") + ("[...]" if len(str(self.exp.before)) > 50 else ""),
@@ -211,7 +202,7 @@ class ConnectionBase(object):
             self.log("caught EOF/TIMEOUT on last expect; closing connections")
             self.close()
             raise e
-        return out
+        return self._prep_cmdoutput(self.exp.before, prepped_msg, do_retcode)
 
     def _prep_cmdmessage(self, msg, do_retcode=True):
         """ prepares a command message before it is delivered to pexpect
@@ -249,6 +240,7 @@ class ConnectionBase(object):
             return None, out
         #remove shell line breaks
         prepped_out = out.replace(" \r", "")
+        prepped_out = prepped_out.replace("\r\r\n", "")
         #remove the \r from \r\n
         prepped_out = prepped_out.replace("\r","")
         # remove cmd line
